# integrate.ai Command Line Interface

A CLI that enables users to interact with integrate.ai's software.

This tool allows users to manage client and sdk packages. Use the integate.ai sdk to seamlessly integrate federated learning and analytics workflows directly into your product.

## Installation

integrate-ai requires `Python >= 3.8`

```
pip install integrate-ai
```

## Quick Start

Create a new IAI token through the integrate.ai UI.

### Install integrate-ai-sdk

```
iai sdk install --token <IAI_TOKEN> 
```

### Pull integrate.ai docker client

```
iai client pull --token <IAI_TOKEN> 
```

### Run integrate.ai training session

```
iai client train --token <IAI_TOKEN> --session <SESSION_ID> --train_path <PATH_TO_TRAINING_DATA> --test_path <PATH_TO_TEST_DATA> --batch_size 5
```
